function BaselineChannelNoise(datapath)
% Called from CheckData 
% djm 27/2/07

cd(fullfile(datapath,'ContinuousData'))

% determine baseline period
fprintf('\nDetermining baseline period...')
files=dir('STI10*data.mat');
N=length(files);
mint=Inf;
for f=1:N
    load(fullfile(datapath,'ContinuousData',files(f).name));
    t=1; voff=B(1);
    try
        while B(t)==voff
            t=t+1;
        end
    catch
        continue % no trigger in file
    end
    if t>1 & t<mint; mint=t; end;
end

files=dir('*data.mat');
N=length(files);
vMag=[];
vGrad=[];
mMag=[];
mGrad=[];
nmMag={};
nmGrad={};
fprintf('\nCalculating baseline variance per channel:\n.......')
for f=1:N
    fprintf('\b\b\b\b\b\b\b%7s',strrep(files(f).name,'_data.mat',''))
    switch files(f).name(1:3)
        case 'MEG'
            %axes(ax(str2num(files(f).name(end-9))));
            load(fullfile(datapath,'ContinuousData',files(f).name));
            bl=B(1:mint);
            if files(f).name(end-9)=='1'
                vMag=[vMag; var(bl)];
                mMag=[mMag; mean(bl)];
                nmMag=[nmMag strrep(files(f).name,'_data.mat','')];
            else
                vGrad=[vGrad; var(bl)];
                mGrad=[mGrad; mean(bl)];
                nmGrad=[nmGrad strrep(files(f).name,'_data.mat','')];
            end
        case 'MIS'
            continue
        case 'STI'
            continue
        otherwise
            error('Unrecognised channel type')
            return
    end
end

% label a few sensors
pmMag=1:length(vMag);
pmGrad=1:length(vGrad);
pvMag=1:length(vMag);
pvGrad=1:length(vGrad);
nvMag=nmMag;
nvGrad=nmGrad;

m_mMag=mean(mMag);
sd_mMag=std(mMag);
m_mGrad=mean(mGrad);
sd_mGrad=std(mGrad);
m_vMag=mean(vMag);
sd_vMag=std(vMag);
m_vGrad=mean(vGrad);
sd_vGrad=std(vGrad);

pvMag(vMag>(m_vMag-3*sd_vMag) & vMag<(m_vMag+3*sd_vMag))=[];
pvGrad(vGrad>(m_vGrad-3*sd_vGrad) & vGrad<(m_vGrad+3*sd_vGrad))=[];
pmMag(mMag>(m_mMag-3*sd_mMag) & mMag<(m_mMag+3*sd_mMag))=[];
pmGrad(mGrad>(m_mGrad-3*sd_mGrad) & mGrad<(m_mGrad+3*sd_mGrad))=[];
nvMag(vMag>(m_vMag-3*sd_vMag) & vMag<(m_vMag+3*sd_vMag))=[];
nvGrad(vGrad>(m_vGrad-3*sd_vGrad) & vGrad<(m_vGrad+3*sd_vGrad))=[];
nmMag(mMag>(m_mMag-3*sd_mMag) & mMag<(m_mMag+3*sd_mMag))=[];
nmGrad(mGrad>(m_mGrad-3*sd_mGrad) & mGrad<(m_mGrad+3*sd_mGrad))=[];

fprintf('\b\b\b\b\b\b\bPlotting variances...\n')

set(0,'Units','pixels');
screen=get(0,'ScreenSize');
figure(10)

% set up axes
titles={'Magnetometers','Magnetometers','Gradiometers','Gradiometers'};
for a=1:length(titles)
    ax(a)=subplot(length(titles),1,a,'align');
    set(gca,'FontSize',8);
    yl=ylim; xl=xlim;
    xlabel(titles(a));
    if mod(a,2)==0
        ylabel('Signal variance before 1st trigger');
    else
        ylabel('Mean signal before 1st trigger');
    end
    set(gca,'ytick',[]); 
    set(gca,'TickDir','out')
    pos=get(gca,'Position');
    pos(3)=pos(3)*1.1;
    set(gca,'Position',pos);
    axis tight; box off; drawnow
    hold on
end

axes(ax(1))
title(sprintf('Time before first trigger = %3.2fs; Dashed lines indicate 3 standard deviations above and below the mean.',mint/sf))
bar(mMag,1); 
hold on
plot([0.5 length(mMag)],[m_mMag+3*sd_mMag m_mMag+3*sd_mMag],'r--')
plot([0.5 length(mMag)],[m_mMag-3*sd_mMag m_mMag-3*sd_mMag],'r--')
set(gca,'xtick',pmMag);
set(gca,'xticklabel',nmMag)
axis tight; box off
set(gca,'yticklabel',ylim)
set(gca,'ytick',ylim)

axes(ax(2))
bar(vMag,1); 
hold on
plot([0.5 length(vMag)],[m_vMag+3*sd_vMag m_vMag+3*sd_vMag],'r--')
plot([0.5 length(vMag)],[m_vMag-3*sd_vMag m_vMag-3*sd_vMag],'r--')
set(gca,'xtick',pvMag);
set(gca,'xticklabel',nvMag)
axis tight; box off
set(gca,'yticklabel',ylim)
set(gca,'ytick',ylim)

axes(ax(3))
bar(mGrad,1); 
hold on
plot([0.5 length(mGrad)],[m_mGrad+3*sd_mGrad m_mGrad+3*sd_mGrad],'r--')
plot([0.5 length(mGrad)],[m_mGrad-3*sd_mGrad m_mGrad-3*sd_mGrad],'r--')
set(gca,'xtick',pmGrad);
set(gca,'xticklabel',nmGrad)
axis tight; box off
set(gca,'yticklabel',ylim)
set(gca,'ytick',ylim)

axes(ax(4))
bar(vGrad,1);
hold on
plot([0.5 length(vGrad)],[m_vGrad+3*sd_vGrad m_vGrad+3*sd_vGrad],'r--')
plot([0.5 length(vGrad)],[m_vGrad-3*sd_vGrad m_vGrad-3*sd_vGrad],'r--')
set(gca,'xtick',pvGrad);
set(gca,'xticklabel',nvGrad)
axis tight; box off
set(gca,'yticklabel',ylim)
set(gca,'ytick',ylim)
 
cd(datapath)
set(gcf,'Position',screen);
orient landscape; print('-dtiff','Summary_BaselineChannelNoise')
delete(10)

return