function CheckData(varargin)
% FORMAT CheckData(datapath,avedatafile,rawdatafile)
%
% datapath      - location of .fif files
% avedatafile   - filename containing averaged data (or '' to ignore)
% rawdatafile   - filename containing continuous data (or '' to ignore)
%
% Reads averaged and continuous data from fif files and saves as mat files
% Converts raw data to floating point format using MaxFilter if necessary
% Prints summary plots of average time courses
% Prints summary plots of signal variance per channel 
% Needs to be run from machine l21 !! 
%
% djm 27/2/07
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% check inputs
if nargin==0
    fprintf('\n!!! No data specified: Using default test data !!!\n')
    varargin{1}='/imaging/dm01/MEG/CDApilot';
    varargin{2}='070212_rc_djm_vstm_realdata.fif';
    varargin{3}='070212_rc_djm_vstm_realdata_raw.fif';
elseif nargin<3
    fprintf('\nPlease specify the data path and at least one file to process.\nFORMAT CheckData(datapath,avedatafile,rawdatafile)\n')
    return
end;
for f=2:length(varargin)
    if strcmp(varargin{f},'')+exist(fullfile(varargin{1},varargin{f}))==0
        fprintf('\nCould not find %s\nFORMAT CheckData(datapath,avedatafile,rawdatafile)\n',fullfile(varargin{1},varargin{f}))
        return
    end
end

addpath '/imaging/dm01/MoreTools/MegTools'
addpath '/imaging/dm01/MoreTools/MegTools/MyMEGtools'
fprintf('\nAnalysing CBU MEG data:\n')
try; delete(10); catch; end;

% get channel information
if ~strcmp(varargin{2},'')
    [ch_name, ch_type, ch_number, ch_coiltype, ch_t]=channames(fullfile(varargin{1},varargin{2}));
else
    [ch_name, ch_type, ch_number, ch_coiltype, ch_t]=channames(fullfile(varargin{1},varargin{3}));
end

if ~strcmp(varargin{2},'')
    % convert averaged data from fif to mat
    if exist(fullfile(varargin{1},'ERFs'))==0; mkdir(fullfile(varargin{1},'ERFs'));end
    if length(dir(fullfile(varargin{1},'ERFs')))>2
        fprintf('\nAveraged data already converted.\n')
    else
        fprintf('\nTrying to load averaged data from fif file...')
        try
            ConvertAveragedData(varargin{1},varargin{2})
        catch
            fprintf('Failed.\n')
            return
        end
    end
    
    % plot summary
    PlotERFData(varargin{1})
end

if ~strcmp(varargin{3},'')
    % convert continuous data from fif to mat
    if exist(fullfile(varargin{1},'ContinuousData'))==0; mkdir(fullfile(varargin{1},'ContinuousData'));end
    if length(dir(fullfile(varargin{1},'ContinuousData')))>2
        fprintf('\nContinuous data already converted.\n')
    else
        fprintf('\nTrying to load continuous data from fif file...')
        try
            ConvertRawData(varargin{1},varargin{3},ch_name)
        catch
            fprintf('Failed.\n')
            return
        end
    end

    % plot summary
    BaselineChannelNoise(varargin{1})
end

fprintf('\nFinished.\n\r')

return
